/*
 * @(#)CustomerRec.java	0.1 96/05/07 Tom McGinn
 *
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 * THIS SOFTWARE IS NOT DESIGNED OR INTENDED FOR USE OR RESALE AS ON-LINE
 * CONTROL EQUIPMENT IN HAZARDOUS ENVIRONMENTS REQUIRING FAIL-SAFE
 * PERFORMANCE, SUCH AS IN THE OPERATION OF NUCLEAR FACILITIES, AIRCRAFT
 * NAVIGATION OR COMMUNICATION SYSTEMS, AIR TRAFFIC CONTROL, DIRECT LIFE
 * SUPPORT MACHINES, OR WEAPONS SYSTEMS, IN WHICH THE FAILURE OF THE
 * SOFTWARE COULD LEAD DIRECTLY TO DEATH, PERSONAL INJURY, OR SEVERE
 * PHYSICAL OR ENVIRONMENTAL DAMAGE ("HIGH RISK ACTIVITIES").  SUN
 * SPECIFICALLY DISCLAIMS ANY EXPRESS OR IMPLIED WARRANTY OF FITNESS FOR
 * HIGH RISK ACTIVITIES.
 */

//package broker.database;

import java.io.Serializable;
import java.util.*;

// CustomerRec class
// This class represents a single customer record in the
// database, including the number of shares the customer 
// owns.
//
public class CustomerRec implements Serializable {

	private String ssn;
	private String name;
	private String addr;
	private Vector portfolio;

	// Constructors
	public CustomerRec (String ssn, String name, String addr, 
		Vector portfolio) {
		this.ssn = ssn;
		this.name = name;
		this.addr = addr;
		this.portfolio = portfolio;
	}

	public CustomerRec (String ssn, String name, String addr) {
		this (ssn, name, addr, null);
	}

	public CustomerRec (String ssn) {
		this (ssn, null, null, null);
	}

	public CustomerRec () {
		this (null, null, null, null);
	}

	// Accessor methods

	public String getSSN () {
		return ssn;
	}

	public String getName () {
		return name;
	}

	public String getAddr () {
		return addr;
	}

	// Get and return the portfolio for this customer
	// This method will return the Vector object that contains
	// the portfolio
	public Vector getPortfolio () {
		return portfolio;
	}

	// Mutator methods - note you cannot change the ssn

	public void setName (String newName) {
		name = newName;
	}

	public void setAddr (String newAddr) {
		addr = newAddr;
	}

	public void setPortfolio (Vector newPortfolio) {
		portfolio = newPortfolio;
	}
}